# Presentations and Publications
## Publications
[![DOI 10.2172/1894867](https://img.shields.io/badge/DOI-10.2172%2F1894867-brightgreen?link=https://doi.org/10.2172/1894867)](https://www.osti.gov/biblio/1894867)

Please cite our below publication if you use this software in your studies!

Hammond, Rob, & Cooperman, Aubryn. Windfarm Operations and Maintenance cost-Benefit Analysis Tool (WOMBAT). United States. https://doi.org/10.2172/1894867

```bibtex
@techreport{hammond2022wombat,
    title = {Windfarm Operations and Maintenance cost-Benefit Analysis Tool (WOMBAT)},
    author = {Hammond, Rob and Cooperman, Aubryn},
    doi = {10.2172/1894867},
    url = {https://www.osti.gov/biblio/1894867},
    place = {United States},
    year = {2022},
    month = {10},
    institution = {National Renewable Energy Lab. (NREL)},
}
```

## 2023 NAWEA WindTech Workshop

This document is the actual presentation given in associating with the conference
workshop. Please also see the [workshop's homepage](/workshops/nawea_wind_tech_2023).
<br/>
{download}`presentation PDF <../presentation_material/nawea_2023_wombat_tutorial_87913.pdf>`
| [NREL Publications](https://www.nrel.gov/docs/fy24osti/87913.pdf)

(presentations:fy20-doe)=
## FY20 DOE Presentation

This document is a link to the Fiscal Year 2020 DOE presentation on the first prototype
of the model.
<br/>
{download}`presentation PDF <../presentation_material/operations_and_maintenance_model_FY20.pdf>`

(presentations:code-comparison)=
## Code-to-Code Comparison

This document serves as a demonstration of the capabilities of this work in reference to
two major works to document simulated O&M results from various industry and research
software systems. Here we compare our software to the published results from
Dinwoodie, et al., 2015 [^dinwoodie2015reference] and IEA, 2016 [^smart2016iea].
<br/>
{download}`presentation PDF <../presentation_material/code_comparison.pdf>`


## IEA Task 26 Presentation

This presentation was given to the IEA Task Force responsible for [^smart2016iea]
as a demonstration of NREL's efforts on O&M model development.
<br/>
{download}`presentation PDF <../presentation_material/WOMBAT_IEA_task_26_presentation_6_May_2021.pdf>`

[^dinwoodie2015reference]: Iain Dinwoodie, Ole-Erik V Endrerud, Matthias Hofmann, Rebecca Martin, and Iver Bakken Sperstad. Reference cases for verification of operation and maintenance simulation models for offshore wind farms. *Wind Engineering*, 39(1):1–14, 2015.
[^smart2016iea]: Gavin Smart, Aaron Smith, Ethan Warner, Iver Bakken Sperstad, Bob Prinsen, and Roberto Lacal-Arantegui. Iea wind task 26: offshore wind farm baseline documentation. Technical Report, National Renewable Energy Lab.(NREL), Golden, CO (United States), 2016.
